@@ -14,8 +14,6 @@ use regex::Regex;
 use strum::IntoEnumIterator;
 use versions::Versioning;
 
-use crate::backend::asdf::Asdf;
-use crate::backend::cargo::CargoBackend;
 use crate::cli::args::BackendArg;
 use crate::config::{Config, Settings};
 use crate::file::{display_path, remove_all, remove_all_with_warning};
@@ -32,14 +30,16 @@ use self::backend_meta::BackendMeta;
 pub mod asdf;
 pub mod backend_meta;
 pub mod cargo;
+mod external_plugin_cache;
 pub mod go;
 pub mod npm;
 pub mod pipx;
 pub mod spm;
 pub mod ubi;
+pub mod vfox;
 
 pub type ABackend = Arc<dyn Backend>;
-pub type BackendMap = BTreeMap<BackendArg, ABackend>;
+pub type BackendMap = BTreeMap<String, ABackend>;
 pub type BackendList = Vec<ABackend>;
 
 #[derive(
@@ -65,6 +65,7 @@ pub enum BackendType {
     Pipx,
     Spm,
     Ubi,
+    Vfox,
 }
 
 impl Display for BackendType {
@@ -73,49 +74,43 @@ impl Display for BackendType {
     }
 }
 
-static FORGES: Mutex<Option<BackendMap>> = Mutex::new(None);
+static TOOLS: Mutex<Option<BackendMap>> = Mutex::new(None);
 
-fn load_backends() -> BackendMap {
-    let mut backends = FORGES.lock().unwrap();
-    if let Some(backends) = &*backends {
+fn load_tools() -> BackendMap {
+    if let Some(backends) = TOOLS.lock().unwrap().as_ref() {
         return backends.clone();
     }
-    let mut plugins = CORE_PLUGINS.clone();
-    plugins.extend(Asdf::list().expect("failed to list plugins"));
-    plugins.extend(list_installed_backends().expect("failed to list backends"));
+    let mut tools = CORE_PLUGINS
+        .iter()
+        .map(|(_, p)| p.clone())
+        .collect::<Vec<ABackend>>();
     let settings = Settings::get();
-    plugins.retain(|plugin| !settings.disable_tools.contains(plugin.id()));
-    let plugins: BackendMap = plugins
+    if settings.asdf {
+        tools.extend(asdf::AsdfBackend::list().expect("failed to list asdf plugins"));
+    }
+    if settings.vfox {
+        tools.extend(vfox::VfoxBackend::list().expect("failed to list vfox plugins"));
+    }
+    tools.extend(list_installed_backends().expect("failed to list backends"));
+    tools.retain(|plugin| !settings.disable_tools.contains(plugin.id()));
+    let tools: BackendMap = tools
         .into_iter()
-        .map(|plugin| (plugin.fa().clone(), plugin))
+        .map(|plugin| (plugin.id().to_string(), plugin))
         .collect();
-    *backends = Some(plugins.clone());
-    plugins
+    *TOOLS.lock().unwrap() = Some(tools.clone());
+    tools
 }
 
 fn list_installed_backends() -> eyre::Result<BackendList> {
     Ok(file::dir_subdirs(&dirs::INSTALLS)?
         .into_par_iter()
-        .map(|dir| {
-            let id = BackendMeta::read(&dir).id;
-            let fa: BackendArg = id.as_str().into();
-            match fa.backend_type {
-                BackendType::Asdf => Arc::new(Asdf::new(fa.name)) as ABackend,
-                BackendType::Cargo => Arc::new(CargoBackend::new(fa.name)) as ABackend,
-                BackendType::Core => Arc::new(Asdf::new(fa.name)) as ABackend,
-                BackendType::Npm => Arc::new(npm::NPMBackend::new(fa.name)) as ABackend,
-                BackendType::Go => Arc::new(go::GoBackend::new(fa.name)) as ABackend,
-                BackendType::Pipx => Arc::new(pipx::PIPXBackend::new(fa.name)) as ABackend,
-                BackendType::Spm => Arc::new(spm::SPMBackend::new(fa.name)) as ABackend,
-                BackendType::Ubi => Arc::new(ubi::UbiBackend::new(fa.name)) as ABackend,
-            }
-        })
+        .map(|dir| arg_to_backend(BackendMeta::read(&dir).into()))
         .filter(|f| f.fa().backend_type != BackendType::Asdf)
         .collect())
 }
 
 pub fn list() -> BackendList {
-    load_backends().values().cloned().collect()
+    load_tools().values().cloned().collect()
 }
 
 pub fn list_backend_types() -> Vec<BackendType> {
@@ -123,28 +118,33 @@ pub fn list_backend_types() -> Vec<BackendType> {
 }
 
 pub fn get(fa: &BackendArg) -> ABackend {
-    if let Some(backend) = load_backends().get(fa) {
+    if let Some(backend) = load_tools().get(&fa.short) {
         backend.clone()
     } else {
-        let mut m = FORGES.lock().unwrap();
+        let mut m = TOOLS.lock().unwrap();
         let backends = m.as_mut().unwrap();
-        let name = fa.name.to_string();
+        let fa = fa.clone();
         backends
-            .entry(fa.clone())
-            .or_insert_with(|| match fa.backend_type {
-                BackendType::Asdf => Arc::new(Asdf::new(name)),
-                BackendType::Cargo => Arc::new(CargoBackend::new(name)),
-                BackendType::Core => Arc::new(Asdf::new(name)),
-                BackendType::Npm => Arc::new(npm::NPMBackend::new(name)),
-                BackendType::Go => Arc::new(go::GoBackend::new(name)),
-                BackendType::Pipx => Arc::new(pipx::PIPXBackend::new(name)),
-                BackendType::Spm => Arc::new(spm::SPMBackend::new(name)),
-                BackendType::Ubi => Arc::new(ubi::UbiBackend::new(name)),
-            })
+            .entry(fa.short.clone())
+            .or_insert_with(|| arg_to_backend(fa))
             .clone()
     }
 }
 
+pub fn arg_to_backend(ba: BackendArg) -> ABackend {
+    match ba.backend_type {
+        BackendType::Asdf => Arc::new(asdf::AsdfBackend::from_arg(ba)),
+        BackendType::Cargo => Arc::new(cargo::CargoBackend::from_arg(ba)),
+        BackendType::Core => Arc::new(asdf::AsdfBackend::from_arg(ba)),
+        BackendType::Npm => Arc::new(npm::NPMBackend::from_arg(ba)),
+        BackendType::Go => Arc::new(go::GoBackend::from_arg(ba)),
+        BackendType::Pipx => Arc::new(pipx::PIPXBackend::from_arg(ba)),
+        BackendType::Spm => Arc::new(spm::SPMBackend::from_arg(ba)),
+        BackendType::Ubi => Arc::new(ubi::UbiBackend::from_arg(ba)),
+        BackendType::Vfox => Arc::new(vfox::VfoxBackend::from_arg(ba)),
+    }
+}
+
 impl From<BackendArg> for ABackend {
     fn from(fa: BackendArg) -> Self {
         get(&fa)
@@ -159,7 +159,7 @@ impl From<&BackendArg> for ABackend {
 
 pub trait Backend: Debug + Send + Sync {
     fn id(&self) -> &str {
-        &self.fa().id
+        &self.fa().short
     }
     fn name(&self) -> &str {
         &self.fa().name
@@ -559,5 +559,5 @@ impl Ord for dyn Backend {
 
 #[cfg(test)]
 pub fn reset() {
-    *FORGES.lock().unwrap() = None;
+    *TOOLS.lock().unwrap() = None;
 }
