@@ -16,7 +16,7 @@ use crate::toolset::ToolRequest;
 
 #[derive(Debug)]
 pub struct PIPXBackend {
-    fa: BackendArg,
+    ba: BackendArg,
     remote_version_cache: CacheManager<Vec<String>>,
     latest_version_cache: CacheManager<Option<String>>,
 }
@@ -27,7 +27,7 @@ impl Backend for PIPXBackend {
     }
 
     fn fa(&self) -> &BackendArg {
-        &self.fa
+        &self.ba
     }
 
     fn get_dependencies(&self, _tvr: &ToolRequest) -> eyre::Result<Vec<BackendArg>> {
@@ -101,16 +101,15 @@ impl Backend for PIPXBackend {
 }
 
 impl PIPXBackend {
-    pub fn new(name: String) -> Self {
-        let fa = BackendArg::new(BackendType::Pipx, &name);
+    pub fn from_arg(ba: BackendArg) -> Self {
         Self {
             remote_version_cache: CacheManager::new(
-                fa.cache_path.join("remote_versions-$KEY.msgpack.z"),
+                ba.cache_path.join("remote_versions-$KEY.msgpack.z"),
             ),
             latest_version_cache: CacheManager::new(
-                fa.cache_path.join("latest_version-$KEY.msgpack.z"),
+                ba.cache_path.join("latest_version-$KEY.msgpack.z"),
             ),
-            fa,
+            ba,
         }
     }
 }
