@@ -8,12 +8,15 @@ use crate::cli::args::BackendArg;
 pub fn commands() -> Vec<Command> {
     backend::list()
         .into_par_iter()
-        .flat_map(|p| {
-            p.external_commands().unwrap_or_else(|e| {
-                let p = p.id();
-                warn!("failed to load external commands for plugin {p}: {e:#}");
-                vec![]
-            })
+        .flat_map(|b| {
+            if let Some(p) = b.plugin() {
+                return p.external_commands().unwrap_or_else(|e| {
+                    let p = p.name();
+                    warn!("failed to load external commands for plugin {p}: {e:#}");
+                    vec![]
+                });
+            }
+            vec![]
         })
         .collect()
 }
@@ -24,13 +27,15 @@ pub fn execute(fa: &BackendArg, args: &ArgMatches) -> Result<()> {
         .find(|c| c.get_name() == fa.to_string())
     {
         if let Some((subcommand, matches)) = args.subcommand() {
-            let plugin = backend::get(fa);
+            let backend = backend::get(fa);
             let args: Vec<String> = matches
                 .get_raw("args")
                 .unwrap_or_default()
                 .map(|s| s.to_string_lossy().to_string())
                 .collect();
-            plugin.execute_external_command(subcommand, args)?;
+            if let Some(p) = backend.plugin() {
+                p.execute_external_command(subcommand, args)?;
+            }
         } else {
             cmd.print_help().unwrap();
         }
