@@ -4,9 +4,9 @@ use std::sync::Arc;
 use console::{pad_str, style, Alignment};
 use eyre::Result;
 
+use crate::backend::Backend;
 use crate::cli::args::ToolArg;
 use crate::config::Config;
-use crate::forge::Forge;
 use crate::toolset::{ToolVersion, ToolsetBuilder};
 
 /// Shows outdated tool versions
@@ -31,10 +31,10 @@ impl Outdated {
         let tool_set = self
             .tool
             .iter()
-            .map(|t| t.forge.clone())
+            .map(|t| t.backend.clone())
             .collect::<HashSet<_>>();
         ts.versions
-            .retain(|_, tvl| tool_set.is_empty() || tool_set.contains(&tvl.forge));
+            .retain(|_, tvl| tool_set.is_empty() || tool_set.contains(&tvl.backend));
         let outdated = ts.list_outdated_versions();
         if outdated.is_empty() {
             info!("All tools are up to date");
@@ -126,7 +126,7 @@ impl Outdated {
     }
 }
 
-type OutputVec = Vec<(Arc<dyn Forge>, ToolVersion, String)>;
+type OutputVec = Vec<(Arc<dyn Backend>, ToolVersion, String)>;
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
@@ -147,20 +147,25 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
 
 #[cfg(test)]
 mod tests {
-    use crate::test::change_installed_version;
+    use crate::test::{change_installed_version, reset};
 
     #[test]
-    fn test_current() {
+    fn test_outdated() {
+        reset();
+        assert_cli!("prune");
+        assert_cli!("install");
         assert_cli_snapshot!("outdated");
     }
 
     #[test]
-    fn test_current_with_runtimes() {
+    fn test_outdated_with_runtimes() {
+        reset();
         assert_cli_snapshot!("outdated", "tiny");
     }
 
     #[test]
-    fn test_current_json() {
+    fn test_outdated_json() {
+        reset();
         change_installed_version("tiny", "3.1.0", "3.0.0");
         assert_cli_snapshot!("outdated", "tiny", "--json");
         change_installed_version("tiny", "3.0.0", "3.1.0");
