@@ -4,9 +4,9 @@ use std::fmt;
 use std::fmt::{Display, Formatter};
 use std::path::PathBuf;
 
-use crate::config::Settings;
 use itertools::Itertools;
 
+use crate::config::Settings;
 use crate::dirs;
 
 pub struct PathEnv {
@@ -31,11 +31,19 @@ impl PathEnv {
     }
 
     pub fn to_vec(&self) -> Vec<PathBuf> {
-        let mut paths = self.pre.iter().chain(self.mise.iter()).collect_vec();
+        let mut paths = self
+            .pre
+            .iter()
+            .chain(self.mise.iter())
+            .map(|p| p.to_path_buf())
+            .collect_vec();
         if self.seen_shims {
-            paths.push(&dirs::SHIMS);
+            paths.push(dirs::SHIMS.to_path_buf())
         }
-        paths.into_iter().chain(self.post.iter()).cloned().collect()
+        paths
+            .into_iter()
+            .chain(self.post.iter().map(|p| p.to_path_buf()))
+            .collect()
     }
 
     pub fn join(&self) -> OsString {
@@ -75,10 +83,16 @@ impl FromIterator<PathBuf> for PathEnv {
 
 #[cfg(test)]
 mod tests {
+    use pretty_assertions::assert_eq;
+    use test_log::test;
+
+    use crate::test::reset;
+
     use super::*;
 
     #[test]
     fn test_path_env() {
+        reset();
         let mut path_env = PathEnv::from_iter(
             [
                 "/before-1",
@@ -105,6 +119,7 @@ mod tests {
 
     #[test]
     fn test_path_env_no_mise() {
+        reset();
         let mut path_env = PathEnv::from_iter(
             [
                 "/before-1",
